@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __ABOUTDATA_H__
-#define __ABOUTDATA_H__
+#pragma once
 
 #include <KAboutData>
 
@@ -17,11 +16,3 @@ class AboutData : public KAboutData
 public:
     AboutData();
 };
-
-class AboutGpg4WinData : public KAboutData
-{
-public:
-    AboutGpg4WinData();
-};
-
-#endif // __ABOUTDATA_H__
