@@ -38,12 +38,9 @@ private:
     class Private;
     inline Private *d_func();
     inline const Private *d_func() const;
-    Q_PRIVATE_SLOT(d_func(), void slotControllerDone())
-    Q_PRIVATE_SLOT(d_func(), void slotControllerError(int, QString))
 };
 
 }
 }
 
 #endif // QT_NO_CLIPBOARD
-
