@@ -38,15 +38,7 @@ private:
     class Private;
     inline Private *d_func();
     inline const Private *d_func() const;
-    Q_PRIVATE_SLOT(d_func(), void slotSearchTextChanged(QString))
-    Q_PRIVATE_SLOT(d_func(), void slotNextKey(GpgME::Key))
-    Q_PRIVATE_SLOT(d_func(), void slotKeyListResult(GpgME::KeyListResult))
-    Q_PRIVATE_SLOT(d_func(), void slotImportRequested(std::vector<GpgME::Key>))
-    Q_PRIVATE_SLOT(d_func(), void slotDetailsRequested(GpgME::Key))
-    Q_PRIVATE_SLOT(d_func(), void slotSaveAsRequested(std::vector<GpgME::Key>))
-    Q_PRIVATE_SLOT(d_func(), void slotDialogRejected())
 };
 
 }
 }
-
