@@ -11,8 +11,6 @@
 
 #include <crypto/gui/wizardpage.h>
 
-#include <utils/pimpl_ptr.h>
-
 #include <gpgme++/global.h>
 
 #include <memory>
@@ -73,7 +71,6 @@ public:
 
     void setAdditionalRecipientsInfo(const std::vector<GpgME::Key> &recipients);
 
-    void setRecipients(const std::vector<KMime::Types::Mailbox> &recipients, const std::vector<KMime::Types::Mailbox> &encryptToSelfRecipients);
     std::vector<GpgME::Key> resolvedCertificates() const;
 
     std::shared_ptr<RecipientPreferences> recipientPreferences() const;
@@ -83,11 +80,11 @@ Q_SIGNALS:
     void selectedProtocolChanged();
 
 private:
-    void onNext() override;
+    bool onNext() override;
 
 private:
     class Private;
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
     Q_PRIVATE_SLOT(d, void selectionChanged())
     Q_PRIVATE_SLOT(d, void protocolSelected(int))
     Q_PRIVATE_SLOT(d, void addRecipient())
@@ -100,4 +97,3 @@ private:
 }
 }
 }
-
