@@ -12,11 +12,10 @@
 #include <QObject>
 #include <QString>
 
-#include <utils/pimpl_ptr.h>
-
 #include <gpgme++/global.h>
 
 #include <QPointer>
+
 #include <memory>
 
 namespace Kleo
@@ -81,7 +80,7 @@ private:
 
 private:
     class Private;
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
 };
 
 class Task::Result
@@ -115,7 +114,6 @@ public:
         Mbox,
     };
 
-    virtual QString icon() const;
     virtual QString overview() const = 0;
     virtual QString details() const = 0;
     virtual GpgME::Error error() const = 0;
@@ -128,13 +126,15 @@ public:
     }
     virtual ContentType viewableContentType() const;
 
+    bool isNotepad() const;
+    void setIsNotepad(bool isNotepad);
+
 protected:
-    static QString iconPath(VisualCode code);
     static QString makeOverview(const QString &msg);
 
 private:
     class Private;
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
 };
 }
 }
