@@ -13,10 +13,7 @@
 
 #include <crypto/task.h>
 
-#include <utils/pimpl_ptr.h>
-
 #include <memory>
-
 #include <vector>
 
 namespace Kleo
@@ -29,12 +26,12 @@ class TaskCollection : public QObject
     Q_OBJECT
 public:
     explicit TaskCollection(QObject *parent = nullptr);
-    ~TaskCollection();
+    ~TaskCollection() override;
 
-    std::vector<std::shared_ptr<Task> > tasks() const;
+    std::vector<std::shared_ptr<Task>> tasks() const;
     std::shared_ptr<Task> taskById(int id) const;
 
-    void setTasks(const std::vector<std::shared_ptr<Task> > &tasks);
+    void setTasks(const std::vector<std::shared_ptr<Task>> &tasks);
 
     bool isEmpty() const;
     size_t size() const;
@@ -45,18 +42,16 @@ public:
     bool allTasksHaveErrors() const;
 
 Q_SIGNALS:
-    void progress(const QString &msg, int processed, int total);
+    void progress(int processed, int total);
     void result(const std::shared_ptr<const Kleo::Crypto::Task::Result> &result);
     void started(const std::shared_ptr<Kleo::Crypto::Task> &task);
     void done();
 
 private:
     class Private;
-    kdtools::pimpl_ptr<Private> d;
-    Q_PRIVATE_SLOT(d, void taskProgress(QString, int, int))
+    const std::unique_ptr<Private> d;
     Q_PRIVATE_SLOT(d, void taskResult(std::shared_ptr<const Kleo::Crypto::Task::Result>))
     Q_PRIVATE_SLOT(d, void taskStarted())
 };
 }
 }
-
