@@ -9,12 +9,12 @@
 
 #pragma once
 
+#include <QStringList>
 #include <QWidget>
 
-#include <utils/pimpl_ptr.h>
+#include <memory>
 
 class QString;
-#include <QStringList>
 
 namespace Kleo
 {
@@ -47,7 +47,7 @@ Q_SIGNALS:
 
 private:
     class Private;
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
     Q_PRIVATE_SLOT(d, void slotAdd())
     Q_PRIVATE_SLOT(d, void slotRemove())
     Q_PRIVATE_SLOT(d, void slotUp())
@@ -57,4 +57,3 @@ private:
 
 }
 }
-
