@@ -87,26 +87,14 @@ std::string OpenPGPCard::resetCodeKeyRef()
 const std::vector<KeyPairInfo> &OpenPGPCard::supportedKeys()
 {
     static const std::vector<KeyPairInfo> keyInfos = {
-        {OpenPGPCard::pgpSigKeyRef(), "", "sc", "", ""},
-        {OpenPGPCard::pgpEncKeyRef(), "", "e", "", ""},
-        {OpenPGPCard::pgpAuthKeyRef(), "", "a", "", ""},
+        {OpenPGPCard::pgpSigKeyRef(), "", "sc", {}, ""},
+        {OpenPGPCard::pgpEncKeyRef(), "", "e", {}, ""},
+        {OpenPGPCard::pgpAuthKeyRef(), "", "a", {}, ""},
     };
 
     return keyInfos;
 }
 
-// static
-QString OpenPGPCard::keyDisplayName(const std::string &keyRef)
-{
-    static const QMap<std::string, QString> displayNames = {
-        {OpenPGPCard::pgpSigKeyRef(), i18n("Signature")},
-        {OpenPGPCard::pgpEncKeyRef(), i18n("Encryption")},
-        {OpenPGPCard::pgpAuthKeyRef(), i18n("Authentication")},
-    };
-
-    return displayNames.value(keyRef);
-}
-
 // static
 std::string OpenPGPCard::getAlgorithmName(const std::string &algorithm, const std::string &keyRef)
 {
@@ -152,11 +140,6 @@ void OpenPGPCard::setSupportedAlgorithms(const std::vector<std::string> &algorit
     }
 }
 
-std::string OpenPGPCard::pubkeyUrl() const
-{
-    return cardInfo("PUBKEY-URL");
-}
-
 std::vector<AlgorithmInfo> OpenPGPCard::supportedAlgorithms() const
 {
     std::vector<AlgorithmInfo> algos;
@@ -170,3 +153,8 @@ bool OpenPGPCard::isSupportedAlgorithm(const std::string &algorithm) const
 {
     return Kleo::contains(mAlgorithms, algorithm);
 }
+
+OpenPGPCard *OpenPGPCard::clone() const
+{
+    return new OpenPGPCard{*this};
+}
