@@ -20,7 +20,7 @@ struct AlgorithmInfo;
 struct KeyPairInfo;
 
 /** Class to work with OpenPGP smartcards or compatible tokens */
-class OpenPGPCard: public Card
+class OpenPGPCard : public Card
 {
 public:
     explicit OpenPGPCard(const Card &card);
@@ -35,8 +35,7 @@ public:
     static std::string adminPinKeyRef();
     static std::string resetCodeKeyRef();
 
-    static const std::vector<KeyPairInfo> & supportedKeys();
-    static QString keyDisplayName(const std::string &keyRef);
+    static const std::vector<KeyPairInfo> &supportedKeys();
 
     /**
      * Returns an algorithm name for the algorithm \p algorithm that is suitable
@@ -56,8 +55,6 @@ public:
      */
     void setSupportedAlgorithms(const std::vector<std::string> &algorithms);
 
-    std::string pubkeyUrl() const;
-
     /**
      * Returns a list of algorithm IDs and corresponding display names.
      *
@@ -67,14 +64,18 @@ public:
     std::vector<AlgorithmInfo> supportedAlgorithms() const;
 
     /**
-     * Returns the ID of the default algorithm for this smart card.
+     * Returns true, if the algorithm with ID \p algorithm is supported by this
+     * smart card. Otherwise, returns false.
      */
-    std::string defaultAlgorithm() const;
+    bool isSupportedAlgorithm(const std::string &algorithm) const;
+
+private:
+    OpenPGPCard(const OpenPGPCard &card) = default;
+
+    OpenPGPCard *clone() const override;
 
 private:
     std::vector<std::string> mAlgorithms;
 };
 } // namespace Smartcard
 } // namespace Kleopatra
-
-
