@@ -71,28 +71,15 @@ std::string PIVCard::pukKeyRef()
 const std::vector<KeyPairInfo> &PIVCard::supportedKeys()
 {
     static const std::vector<KeyPairInfo> keyInfos = {
-        {PIVCard::pivAuthenticationKeyRef(), "", "a", "", ""},
-        {PIVCard::cardAuthenticationKeyRef(), "", "a", "", ""},
-        {PIVCard::digitalSignatureKeyRef(), "", "sc", "", ""},
-        {PIVCard::keyManagementKeyRef(), "", "e", "", ""},
+        {PIVCard::pivAuthenticationKeyRef(), "", "a", {}, ""},
+        {PIVCard::cardAuthenticationKeyRef(), "", "a", {}, ""},
+        {PIVCard::digitalSignatureKeyRef(), "", "sc", {}, ""},
+        {PIVCard::keyManagementKeyRef(), "", "e", {}, ""},
     };
 
     return keyInfos;
 }
 
-// static
-QString PIVCard::keyDisplayName(const std::string &keyRef)
-{
-    static const QMap<std::string, QString> displayNames = {
-        {PIVCard::pivAuthenticationKeyRef(), i18n("PIV Authentication Key")},
-        {PIVCard::cardAuthenticationKeyRef(), i18n("Card Authentication Key")},
-        {PIVCard::digitalSignatureKeyRef(), i18n("Digital Signature Key")},
-        {PIVCard::keyManagementKeyRef(), i18n("Key Management Key")},
-    };
-
-    return displayNames.value(keyRef);
-}
-
 // static
 std::vector<AlgorithmInfo> PIVCard::supportedAlgorithms(const std::string &keyRef)
 {
@@ -116,3 +103,8 @@ std::vector<AlgorithmInfo> PIVCard::supportedAlgorithms(const std::string &keyRe
         {"nistp256", i18n("ECDSA (Curve P-256)")},
     };
 }
+
+PIVCard *PIVCard::clone() const
+{
+    return new PIVCard{*this};
+}
