@@ -1,5 +1,5 @@
 /* -*- mode: c++; c-basic-offset:4 -*-
-    uiserver/decryptemailcommand.h
+    uiserver/decryptfilescommand.h
 
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
@@ -17,7 +17,7 @@ namespace Kleo
 class DecryptFilesCommand : public AssuanCommandMixin<DecryptFilesCommand, DecryptVerifyCommandFilesBase>
 {
 public:
-    //DecryptFilesCommand();
+    // DecryptFilesCommand();
     //~DecryptFilesCommand();
 
 private:
@@ -25,6 +25,7 @@ private:
     {
         return Decrypt;
     }
+
 public:
     static const char *staticName()
     {
@@ -33,4 +34,3 @@ public:
 };
 
 }
-
