@@ -11,7 +11,7 @@
 
 #include "assuancommand.h"
 
-#include <utils/pimpl_ptr.h>
+#include <memory>
 
 namespace Kleo
 {
@@ -26,7 +26,7 @@ protected:
     enum Operation {
         SignDisallowed = 0,
         SignAllowed = 1,
-        SignSelected  = 2,
+        SignSelected = 2,
 
         SignMask = SignAllowed | SignSelected,
 
@@ -42,9 +42,11 @@ private:
     {
         return SignSelected | EncryptSelected;
     }
+
 private:
     int doStart() override;
     void doCanceled() override;
+
 public:
     static const char *staticName()
     {
@@ -52,8 +54,9 @@ public:
     }
 
     class Private;
+
 private:
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
 };
 
 class EncryptSignFilesCommand : public Kleo::AssuanCommandMixin<EncryptSignFilesCommand, SignEncryptFilesCommand>
@@ -92,4 +95,3 @@ public:
 };
 
 }
-
