@@ -17,7 +17,6 @@
 #include <Libkleo/KeyListSortFilterProxyModel>
 #include <Libkleo/KeyRearrangeColumnsProxyModel>
 #include <Libkleo/Predicates>
-#include <Libkleo/TreeView>
 
 #include "utils/headerview.h"
 #include "utils/tags.h"
@@ -44,7 +43,7 @@
 
 #include <KLocalizedString>
 #include <KSharedConfig>
-#include <KStandardAction>
+#include <KStandardActions>
 #include <qnamespace.h>
 
 static int tagsColumn;
@@ -63,11 +62,6 @@ public:
     explicit TreeViewInternal(QWidget *parent = nullptr)
         : Kleo::TreeView{parent}
     {
-        connect(this, &TreeView::columnEnabled, this, [this](int column) {
-            if (column == tagsColumn) {
-                Tags::enableTags();
-            }
-        });
     }
 
     QSize minimumSizeHint() const override
@@ -76,28 +70,7 @@ public:
         return QSize(min.width(), min.height() + 5 * fontMetrics().height());
     }
 
-protected:
-    void focusInEvent(QFocusEvent *event) override
-    {
-        QTreeView::focusInEvent(event);
-        // queue the invokation, so that it happens after the widget itself got focus
-        QMetaObject::invokeMethod(this, &TreeViewInternal::forceAccessibleFocusEventForCurrentItem, Qt::QueuedConnection);
-    }
-
 private:
-    void forceAccessibleFocusEventForCurrentItem()
-    {
-        // force Qt to send a focus event for the current item to accessibility
-        // tools; otherwise, the user has no idea which item is selected when the
-        // list gets keyboard input focus
-        const auto current = currentIndex();
-        setCurrentIndex({});
-        setCurrentIndex(current);
-    }
-
-private:
-    QMenu *mHeaderPopup = nullptr;
-
     QList<QAction *> mColumnActions;
 };
 
@@ -227,9 +200,6 @@ void KeyTreeView::restoreLayout(const KConfigGroup &group)
     } else {
         m_onceResized = true;
     }
-    if (!m_view->isColumnHidden(tagsColumn)) {
-        Tags::enableTags();
-    }
 }
 
 void KeyTreeView::init()
@@ -271,13 +241,13 @@ void KeyTreeView::init()
         connect(m_view, &KeyTreeView::customContextMenuRequested, this, [this](const auto &pos) {
             auto menu = new QMenu;
             menu->setAttribute(Qt::WA_DeleteOnClose, true);
-            menu->addAction(KStandardAction::copy(
+            menu->addAction(KStandardActions::copy(
                 this,
                 [this]() {
-                    QGuiApplication::clipboard()->setText(m_view->currentIndex().data(KeyList::ClipboardRole).toString());
+                    QGuiApplication::clipboard()->setText(m_view->currentIndex().data(Kleo::ClipboardRole).toString());
                 },
                 this));
-            menu->popup(m_view->mapToGlobal(pos));
+            menu->popup(m_view->viewport()->mapToGlobal(pos));
         });
     }
 
@@ -656,12 +626,10 @@ void KeyTreeView::initializeColumnSizes()
         return;
     }
     m_onceResized = true;
+    m_view->resizeToContentsLimited();
+
     m_view->setColumnWidth(KeyList::PrettyName, 260);
     m_view->setColumnWidth(KeyList::PrettyEMail, 260);
-
-    for (int i = 2; i < m_view->model()->columnCount(); ++i) {
-        m_view->resizeColumnToContents(i);
-    }
 }
 
 void KeyTreeView::saveStateBeforeModelChange()
@@ -687,12 +655,4 @@ void KeyTreeView::restoreStateAfterModelChange()
     initializeColumnSizes();
 }
 
-void KeyTreeView::keyPressEvent(QKeyEvent *event)
-{
-    if (event == QKeySequence::Copy) {
-        QGuiApplication::clipboard()->setText(view()->currentIndex().data(KeyList::ClipboardRole).toString());
-        event->accept();
-    }
-}
-
 #include "moc_keytreeview.cpp"
